@@ -48,7 +48,7 @@ using namespace ZenLib;
 #define QString2wstring(_DATA) \
     Ztring().From_UTF8(_DATA.toUtf8())
 
-#define VERSION "18.05"
+#define VERSION "23.10"
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) //UWP Application
 #include <QtPlatformHeaders/QWindowsWindowFunctions>
 #include <ZenLib/Os_Utils.h>
@@ -187,22 +187,22 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
 #endif
 
     //tests
-    ui->actionQuit->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
-    ui->actionClose_All->setIcon(style()->standardIcon(QStyle::SP_DialogCloseButton));
-    ui->actionOpen->setIcon(QIcon(":/icon/openfile.svg"));
-    ui->actionOpen_Folder->setIcon(QIcon(":/icon/opendir.svg"));
-    ui->actionAbout->setIcon(QIcon(":/icon/about.svg"));
-    ui->actionExport->setIcon(QIcon(":/icon/export.svg"));
+    ui->actionQuit->setIcon(QIcon::fromTheme("application-exit"));
+    ui->actionClose_All->setIcon(QIcon::fromTheme("dialog-close"));
+    ui->actionOpen->setIcon(QIcon::fromTheme("document-open"));
+    ui->actionOpen_Folder->setIcon(QIcon::fromTheme("document-open-folder"));
+    ui->actionAbout->setIcon(QIcon::fromTheme("help-about"));
+    ui->actionExport->setIcon(QIcon::fromTheme("document-export"));
+    ui->actionPreferences->setIcon(QIcon::fromTheme("configure"));
 
     menuView = new QMenu();
    QActionGroup* menuItemGroup = new QActionGroup(this);
    for(int v=VIEW_EASY;v<NB_VIEW;v++) {
-       QAction* action = new QAction(nameView((ViewMode)v));
+       QAction* action = new QAction(nameView((ViewMode)v), menuItemGroup);
        action->setCheckable(true);
        if(view==v)
            action->setChecked(true);
        action->setProperty("view",v);
-       menuItemGroup->addAction(action);
        ui->menuView->addAction(action);
        menuView->addAction(action);
    }
@@ -210,7 +210,7 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
 
    buttonView = new QToolButton();
    buttonView->setText("view");
-   buttonView->setIcon(QIcon(":/icon/view.svg"));
+   buttonView->setIcon(QIcon::fromTheme("view-list-details"));
    connect(buttonView, SIGNAL(clicked()), this, SLOT(buttonViewClicked()));
    ui->toolBar->addWidget(buttonView);
 
@@ -223,7 +223,7 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
 
     refreshDisplay();
 
-    if(filesnames.count()>1) {
+    if(filesnames.count()>0) {
         openFiles(filesnames);
     }
 
@@ -614,13 +614,30 @@ void MainWindow::refreshDisplay() {
                 xis->setContent(wstring2QString(C->Inform_Get()));
                 ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
                 break;
-            case VIEW_MPEG7:
-                C->Menu_View_MPEG7();
+            case VIEW_MPEG7_Strict:
+                C->Menu_View_MPEG7_Strict();
                 viewWidget = new QTextBrowser();
                 xis = new QDomDocument();
                 xis->setContent(wstring2QString(C->Inform_Get()));
                 ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
                 break;
+
+            case VIEW_MPEG7_Relaxed:
+                C->Menu_View_MPEG7_Relaxed();
+                viewWidget = new QTextBrowser();
+                xis = new QDomDocument();
+                xis->setContent(wstring2QString(C->Inform_Get()));
+                ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
+                break;
+
+            case VIEW_MPEG7_Extended:
+                C->Menu_View_MPEG7_Extended();
+                viewWidget = new QTextBrowser();
+                xis = new QDomDocument();
+                xis->setContent(wstring2QString(C->Inform_Get()));
+                ((QTextBrowser*)viewWidget)->setText(xis->toString(4));
+                break;
+
             case VIEW_XML:
                 C->Menu_View_XML();
                 viewWidget = new QTextBrowser();
@@ -665,7 +682,7 @@ void MainWindow::refreshDisplay() {
         if(C->Count_Get()==1)
             setWindowTitle("MediaInfo - "+shortName(C,wstring2QString(C->Get(0, Stream_General, 0, __T("CompleteName")))));
         else
-            setWindowTitle(Tr("MediaInfo - %n files","window title",(int)C->Count_Get()));
+            setWindowTitle(QString("MediaInfo - %1 ").arg((int)C->Count_Get())+Tr("files","window title"));
 #endif
     }
     setCentralWidget(viewWidget);
@@ -679,8 +696,9 @@ QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
     headers.append(Tr("value"));
     treeWidget->setHeaderLabels(headers);
     unsigned fileCount = (unsigned)C->Count_Get();
-
     QDir dir = getCommonDir(C);
+
+    C->Menu_Option_Preferences_Option(__T("File_ExpandSubs"), __T("1"));
     for (size_t filePos=0; filePos<fileCount; filePos++) {
         //Pour chaque fichier
         QTreeWidgetItem* treeItem = new QTreeWidgetItem(treeWidget,QStringList(shortName(dir,wstring2QString(C->Get(filePos, Stream_General, 0, __T("CompleteName"))))));
@@ -701,8 +719,12 @@ QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
                     A+=" #"+B;
                 }
                 QTreeWidgetItem* node = new QTreeWidgetItem(treeItem,QStringList(A));
+                node->setExpanded(true);
                 treeItem->addChild(node);
 
+                QVector<QTreeWidgetItem*> tree;
+                tree.append(node);
+
                 if(ConfigTreeText::getIndex()==0) {
                     size_t ChampsCount=C->Count_Get(filePos, (stream_t)streamKind, streamPos);
                     for (size_t Champ_Pos=0; Champ_Pos<ChampsCount; Champ_Pos++)
@@ -716,9 +738,27 @@ QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
                             if (D.isEmpty())
                                 D=wstring2QString(C->Get(filePos, (stream_t)streamKind, streamPos, Champ_Pos, Info_Name)); //Texte n'existe pas
 
+                            int level=0;
+                            while (level < D.length() && D[level]==QChar(' '))
+                                level++;
+
+                            if (level)
+                                D=D.mid(level);
+
+                            if (level==tree.count() && tree.back()->childCount())
+                            {
+                                tree.append(tree.back()->child(tree.back()->childCount()-1));
+                                if (tree.back()->columnCount()>1 && tree.back()->text(1)=="Yes")
+                                    tree.back()->setText(1, "");
+                            }
+                            else if (level<tree.count()-1)
+                            {
+                                tree.resize(level+1);
+                            }
+
                             QStringList sl = QStringList(D);
                             sl.append(A);
-                            node->addChild(new QTreeWidgetItem(node,sl));
+                            tree.back()->addChild(new QTreeWidgetItem(tree.back(),sl));
                         }
                     }
                 } else {
@@ -728,16 +768,32 @@ QTreeWidget* MainWindow::showTreeView(bool completeDisplay) {
                         QString B=wstring2QString(C->Get(filePos, (stream_t)streamKind, streamPos, QString2wstring(field), Info_Name_Text));
                         if (B.isEmpty())
                             B=wstring2QString(C->Get(filePos, (stream_t)streamKind, streamPos, QString2wstring(field), Info_Name));
+
+                        int level=0;
+                        while (level < B.length() && B[level]==QChar(' '))
+                            level++;
+
+                        if (level)
+                            B=B.mid(level);
+
+                        if (level==tree.count() && tree.back()->childCount())
+                           tree.append(tree.back()->child(tree.back()->childCount()-1));
+                        else if (level<tree.count()-1)
+                            tree.resize(level+1);
+
                         QStringList sl = QStringList(B);
                         sl.append(A);
-                        node->addChild(new QTreeWidgetItem(node,sl));
+                        tree.back()->addChild(new QTreeWidgetItem(tree.back(),sl));
                     }
                 }
             }
         }
     }
-    if(C->Count_Get()<=1)
-        treeWidget->expandAll();
+    C->Menu_Option_Preferences_Option(__T("File_ExpandSubs"), __T("0"));
+    if(C->Count_Get()<=1 && treeWidget->topLevelItem(0))
+    {
+        treeWidget->topLevelItem(0)->setExpanded(true);
+    }
     treeWidget->resizeColumnToContents(0);
     return treeWidget;
 }
@@ -958,7 +1014,7 @@ void MainWindow::on_actionOpen_Folder_triggered()
 
 void MainWindow::on_actionAbout_triggered()
 {
-    About a(VERSION, this);
+    About a(this);
     a.exec();
 }
 
@@ -1105,8 +1161,16 @@ void MainWindow::on_actionExport_triggered()
             C->Menu_View_NISO_Z39_87();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
-        case Export::MPEG7:
-            C->Menu_View_MPEG7();
+        case Export::MPEG7_Strict:
+            C->Menu_View_MPEG7_Strict();
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
+        case Export::MPEG7_Relaxed:
+            C->Menu_View_MPEG7_Relaxed();
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
+        case Export::MPEG7_Extended:
+            C->Menu_View_MPEG7_Extended();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
         default:
@@ -1124,6 +1188,12 @@ void MainWindow::on_actionAdvanced_Mode_toggled(bool checked)
     refreshDisplay();
 }
 
+void MainWindow::on_actionFull_Parse_toggled(bool checked)
+{
+    C->MI->Option_Static(__T("ParseSpeed"), checked?__T("1"):__T("0.5"));
+    refreshDisplay();
+}
+
 void MainWindow::on_actionClose_All_triggered()
 {
     C->Menu_File_Open_Files_Begin(true);
