@@ -20,6 +20,10 @@
 #ifndef MEDIAINFOGUI_ABOUT_NO
     #include "GUI/VCL/GUI_About.h"
 #endif
+#ifndef MEDIAINFOGUI_PLUGIN_NO
+    #include "GUI/VCL/GUI_Plugin.h"
+#endif
+
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -155,6 +159,15 @@ __fastcall TMainF::TMainF(TComponent* Owner)
     Donates.push_back(Donate___);
     Donate_Current=NULL;
 
+    //Footer
+    Footer_Button=new TButton(this);
+    Footer_Button->Font->Size=12;
+    Footer_Button->Height=32;
+    Footer_Button->Parent=Page;
+    Footer_Button->Align=alBottom;
+    Footer_Button->OnClick=&Footer_ButtonClick;
+    Footer_Button->Visible=false;
+
     //Configuration of properties
     Page->Top=-6; //Not done with BCB because I want to easy select tabs in it
     Page->TabHeight=1; //Not done with BCB because I want to easy select tabs in it
@@ -176,7 +189,7 @@ void __fastcall TMainF::GUI_Configure()
     if (Screen->Width>=1024)
         Width=700;
     if (Screen->Width>=1280)
-        Width=820;
+        Width=830;
     if (Screen->Height>=768)
         Height=500;
     if (Screen->Height>=1024)
@@ -215,7 +228,10 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("XML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MIXML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("JSON")) {M_View_JSONClick(NULL); M_View_JSON->Checked=true;}
-    else if (Prefs->Config(__T("Output"))==__T("MPEG-7")) {M_View_MPEG7Click(NULL); M_View_MPEG7->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("Graph_Svg")) {M_View_Graph_SvgClick(NULL); M_View_Graph_Svg->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("MPEG-7_Strict")) {M_View_MPEG7_StrictClick(NULL); M_View_MPEG7_Strict->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("MPEG-7_Relaxed")) {M_View_MPEG7_RelaxedClick(NULL); M_View_MPEG7_Relaxed->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("MPEG-7_Extended")) {M_View_MPEG7_ExtendedClick(NULL); M_View_MPEG7_Extended->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) {M_View_PBCoreClick(NULL); M_View_PBCore->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_2.0")) {M_View_PBCore2Click(NULL); M_View_PBCore2->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.5")) {M_View_EBUCore_1_5Click(NULL); M_View_EBUCore_1_5->Checked=true;}
@@ -593,11 +609,16 @@ void __fastcall TMainF::Translate()
         }
         */
     }
-    //if (Prefs->Donated) //No more
+
+    M_Sponsor->Visible=false;
+    if (Prefs->Sponsored && !Prefs->Donated && !Prefs->Translate(__T("SponsorMessage")).empty() && !Prefs->Translate(__T("SponsorMessage")).empty())
     {
-        M_Tektronix->Visible=false;
-        Tool_Tektronix->Visible=false;
+        M_Sponsor->Caption =  + Prefs->Translate(__T("SponsorMessage")).c_str();
+        M_Sponsor->Visible=true;
     }
+
+    //Footer
+    Footer_Button->Caption=L"Go to conformance errors and warnings glossary page";
 }
 
 //---------------------------------------------------------------------------
@@ -782,6 +803,13 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("Details;1"));
         else
             I->Option_Static(__T("Inform"));
+
+        if (!Prefs->Config(__T("InformVersion")).empty())
+            I->Option_Static(__T("Inform_Version"), Prefs->Config(__T("InformVersion")));
+
+        if (!Prefs->Config(__T("InformTimestamp")).empty())
+            I->Option_Static(__T("Inform_Timestamp"), Prefs->Config(__T("InformTimestamp")));
+
         Page_Text_Text->Text=I->Inform().c_str();
 
         //Specific in case of no file
@@ -828,8 +856,22 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("MIXML"));
         else if (M_View_JSON->Checked)
             I->Option_Static(__T("Inform"), __T("JSON"));
-        else if (M_View_MPEG7->Checked)
-            I->Option_Static(__T("Inform"), __T("MPEG-7"));
+        else if (M_View_Graph_Svg->Checked)
+        {
+            if (!Prefs->Config(__T("Graph_Adm_ShowTrackUIDs")).empty())
+                I->Option_Static(__T("Graph_Adm_ShowTrackUIDs"), Prefs->Config(__T("Graph_Adm_ShowTrackUIDs")));
+
+            if (!Prefs->Config(__T("Graph_Adm_ShowChannelFormats")).empty())
+                I->Option_Static(__T("Graph_Adm_ShowChannelFormats"), Prefs->Config(__T("Graph_Adm_ShowChannelFormats")));
+
+            I->Option_Static(__T("Inform"), __T("Graph_Svg"));
+        }
+        else if (M_View_MPEG7_Strict->Checked)
+            I->Option_Static(__T("Inform"), __T("MPEG-7_Strict"));
+        else if (M_View_MPEG7_Relaxed->Checked)
+            I->Option_Static(__T("Inform"), __T("MPEG-7_Relaxed"));
+        else if (M_View_MPEG7_Extended->Checked)
+            I->Option_Static(__T("Inform"), __T("MPEG-7_Extended"));
         else if (M_View_PBCore->Checked)
             I->Option_Static(__T("Inform"), __T("PBCore_1.2"));
         else if (M_View_PBCore2->Checked)
@@ -860,7 +902,67 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), Prefs->Details[Prefs_Custom].Read());
         Ztring S1=I->Inform();
         if (S1.empty())
-            S1=Prefs->Translate(__T("At least one file")).c_str();
+			S1=Prefs->Translate(__T("At least one file")).c_str();
+
+        if (I->Option_Static(__T("Inform_Get"), __T("")) == __T("Graph_Svg"))
+        {
+            S1 = Ztring();
+
+            Ztring InstallFolder = Application->ExeName.c_str();
+            InstallFolder = InstallFolder.substr(0, InstallFolder.rfind(__T("\\")) + 1);
+
+            Ztring State=I->Option_Static(__T("Info_Graph_Svg_Plugin_State"), __T(""));
+            if (State == __T("0") || !File::Exists(InstallFolder+__T("\\Plugin\\Graph\\Template.html"))) //Try to install plugin
+            {
+                TPluginF* P = new TPluginF(this, PLUGIN_GRAPH);
+                if (P->Configure())
+                    P->ShowModal();
+                delete P;
+
+                State = I->Option_Static(__T("Info_Graph_Svg_Plugin_State"), __T(""));
+            }
+
+            if (State == __T("1"))
+            {
+                for (size_t Pos = 0; Pos < I->Count_Get(); Pos++)
+                {
+                    Ztring Svg = I->Inform(Pos);
+                    size_t Pos2 = Svg.find(__T("<svg"));
+                    if (Pos2 != std::string::npos)
+                        Svg = Svg.substr(Pos);
+                    S1 += (Pos2 ? __T("<br/>") : __T("")) + Svg;
+                }
+
+                if (File::Exists(InstallFolder+__T("\\Plugin\\Graph\\Template.html")))
+                {
+                    File F(InstallFolder+__T("\\Plugin\\Graph\\Template.html"));
+                    int8u* Buffer=new int8u[(size_t)F.Size_Get()+1];
+                    size_t Count=F.Read(Buffer, (size_t)F.Size_Get());
+                    if (Count==ZenLib::Error)
+                    {
+                        delete[] Buffer; //Buffer=NULL;
+                        S1=__T("Unable to load graph template");
+                    }
+                    else
+                    {
+                        Buffer[Count]=(int8u)'\0';
+                        Ztring Template=Ztring().From_UTF8((char*)Buffer);
+                        if (Template.FindAndReplace(__T("@SVG@"), S1)==0)
+                            S1=__T("Invalid template");
+                        else
+                            S1=Template;
+                    }
+                    delete[] Buffer; //Buffer=NULL;
+                }
+                else
+                    S1=__T("Graph template not found");
+            }
+            else if (State == __T("0"))
+                S1 = __T("Graph plugin not installed");
+            else
+                S1 = State;
+        }
+
         if (S1.size()>1 && S1[0]=='<' && S1[1]=='h')
         {
             //Supposing this is HTML
@@ -943,8 +1045,6 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
         //0 fichier
     {
         Caption=MEDIAINFO_TITLE;
-        if (Prefs->Donated)
-            Caption+=" - Sponsored by Tektronix";
     }
     else if (FilesCount==1)
         //un fichier
@@ -974,6 +1074,24 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
         M_File_Export->Visible=false;
         Tool_Export->Enabled=false;
     }
+
+     // Show conformance glossary button
+    if (FilesCount>0 && Page!=Page_System)
+    {
+        bool Display=false;
+        size_t FilePos=0;
+        size_t AudioCount=I->Count_Get(FilePos, Stream_Audio, -1);
+        for (size_t AudioPos=0; AudioPos<AudioCount; AudioPos++)
+        {
+            if (I->Get(FilePos, Stream_Audio, AudioPos, __T("ConformanceErrors"))!=__T("") ||
+                I->Get(FilePos, Stream_Audio, AudioPos, __T("ConformanceWarnings"))!=__T(""))
+            {
+                Display=true;
+                break;
+            }
+        }
+        Footer_Button->Visible=Display;
+    }
 }
 
 //***************************************************************************
@@ -1151,10 +1269,26 @@ void __fastcall TMainF::M_View_JSONClick(TObject *Sender)
 }
 
 //---------------------------------------------------------------------------
-void __fastcall TMainF::M_View_MPEG7Click(TObject *Sender)
+void __fastcall TMainF::M_View_MPEG7_StrictClick(TObject *Sender)
 {
-    M_View_MPEG7->Checked=true;
-    ToolBar_View_MPEG7->Checked=true;
+    M_View_MPEG7_Strict->Checked=true;
+    ToolBar_View_MPEG7_Strict->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_MPEG7_RelaxedClick(TObject *Sender)
+{
+    M_View_MPEG7_Relaxed->Checked=true;
+    ToolBar_View_MPEG7_Relaxed->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_MPEG7_ExtendedClick(TObject *Sender)
+{
+    M_View_MPEG7_Extended->Checked=true;
+    ToolBar_View_MPEG7_Extended->Checked=true;
     ChangePage(Page_Custom);
 }
 
@@ -1174,6 +1308,14 @@ void __fastcall TMainF::M_View_NISO_Z39_87Click(TObject *Sender)
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_Graph_SvgClick(TObject *Sender)
+{
+    M_View_Graph_Svg->Checked=true;
+    ToolBar_View_Graph_Svg->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
 {
@@ -1364,10 +1506,10 @@ void __fastcall TMainF::M_Debug_AdvancedClick(TObject *Sender)
 
 //---------------------------------------------------------------------------
 
-void __fastcall TMainF::M_Debug_FullParsingClick(TObject *Sender)
+void __fastcall TMainF::M_Options_FullParsingClick(TObject *Sender)
 {
-    M_Debug_FullParsing->Checked=!M_Debug_FullParsing->Checked;
-    I->Option_Static(__T("ParseSpeed"), M_Debug_FullParsing->Checked?__T("1"):__T("0"));
+    M_Options_FullParsing->Checked=!M_Options_FullParsing->Checked;
+    I->Option_Static(__T("ParseSpeed"), M_Options_FullParsing->Checked?__T("1"):__T("0.5"));
 }
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_Debug_DummyClick(TObject *Sender)
@@ -1737,72 +1879,82 @@ MESSAGE void __fastcall TMainF::HandleDropFiles (TMessage& Msg)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_deClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/de/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/de/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_enClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/en/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/en/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_esClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/es/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/es/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_frClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/fr/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/fr/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_itClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/it/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/it/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_jaClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/ja/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/ja/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_plClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/pl/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/pl/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_zh_CNClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/zh_CN/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/zh_CN/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_zh_TWClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/zh_TW/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/zh_TW/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate___Click(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("MediaInfo/Donate")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, (Ztring(__T("https://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("MediaInfo/Donate")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_NewVersionClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/MediaInfo/?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, (Ztring(__T("https://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/MediaInfo/?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
-void __fastcall TMainF::M_TektronixClick(TObject *Sender)
-{
-    ShellExecute(NULL, NULL, __T("http://www.tek.com/file-based-qc-solutions"), NULL, NULL, SW_SHOWNORMAL);
-}
 //---------------------------------------------------------------------------
+void __fastcall TMainF::M_SponsorClick(TObject *Sender)
+{
+    ShellExecute(NULL, NULL, Prefs->Translate(__T("SponsorUrl")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+}
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::Footer_ButtonClick(TObject *Sender)
+{
+    const Ztring Inform_Save=I->Option(__T("Inform_Get"), __T(""));
+    I->Option(__T("Inform"), __T("Conformance_JSON"));
+
+    const Ztring URL=I->Inform();
+    I->Option(__T("Inform"), Inform_Save);
+    ShellExecute(NULL, NULL, URL.c_str(), NULL, NULL, SW_SHOWNORMAL);
+}
